@@ -245,7 +245,7 @@ GtkWidget* create_settings_dialog(UPnPBrowserSettings* cache)
 	
 	settings_dialog = gtk_dialog_new();
 	gtk_window_set_title(GTK_WINDOW(settings_dialog),
-			     _("UPnP Browser Settings"));
+			     "UPnP Browser Settings");
 	gtk_window_set_type_hint(GTK_WINDOW (settings_dialog),
 				 GDK_WINDOW_TYPE_HINT_DIALOG);
 
